//
//  PauseRunViewController.swift
//  NavigationUI
//
//  Created by hassine othmane on 4/24/20.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import MessageUI


protocol MyPauseRunDelegate{
    
    func stopMyNavigation()
    func manageVoice()
}



public class PauseRunViewController: UIViewController, MFMessageComposeViewControllerDelegate {
    public func messageComposeViewController(_ controller: MFMessageComposeViewController, didFinishWith result: MessageComposeResult) {
        self.dismiss(animated: true, completion: nil)
    }
    
    
    var delegate: MyPauseRunDelegate?
    @IBOutlet weak var continue_btn: UIButton!
    @IBOutlet weak var popup_view: UIView!
    
    @IBOutlet weak var finish_btn: UIButton!
    @IBOutlet weak var container_view: UIView!
    
    @IBOutlet weak var time_imageView: UIImageView!
    @IBOutlet weak var kmTitle_lbl: UILabel!
    @IBOutlet weak var km_lbl: UILabel!
    
    @IBOutlet weak var duration_lbl: UILabel!
    
    @IBOutlet weak var durationTitle_lbl: UILabel!
    
    @IBOutlet weak var timer_lbl: UILabel!
    
    @IBOutlet weak var km_imageView: UIImageView!
    
    
    @IBOutlet weak var audio_switch: UISwitch!
    
    var historic : Historic?
    
    var user : MyUser?
    
    var isMuted : Bool = false
    
    public override func viewDidLoad() {
        super.viewDidLoad()
        finish_btn.primaryStyle(color: UIColor(red: 0.95, green: 0.35, blue: 0.32, alpha: 1.00))
        continue_btn.primaryStyle()
        // Do any additional setup after loading the view.
        popup_view.layer.cornerRadius = 30
        popup_view.layer.masksToBounds = true
        
        let blurEffect = UIBlurEffect(style: UIBlurEffect.Style.dark)
        let blurEffectView = UIVisualEffectView(effect: blurEffect)
        blurEffectView.frame = container_view.bounds
        blurEffectView.autoresizingMask = [.flexibleWidth, .flexibleHeight]
        blurEffectView.alpha = 0.75
        container_view.insertSubview(blurEffectView, belowSubview: popup_view)
        
        duration_lbl.headerStyle(color: UIColor.white)
        km_lbl.headerStyle(color: UIColor.white)
        
        kmTitle_lbl.title1Style(color:  UIColor.white)
        durationTitle_lbl.title1Style(color:  UIColor.white)
        
        km_lbl.text = String(format:"%.1f",Double(historic?.distanceTravelled ?? 0)/1000)
        kmTitle_lbl.text = " km"
        
        duration_lbl.text = String(format:"%.1f",historic?.mediumSpeed ?? 0)
        durationTitle_lbl.text = " km/h"
        timer_lbl.timerCradStyle()
        timer_lbl.text = "\(historic?.time.secondsToHoursMinutesSeconds() ?? 0.secondsToHoursMinutesSeconds())"
        pause_lbl.headerStyle(color: UIColor.white)
        finish_btn.setTitle("finish".localized.uppercased(), for: UIControl.State.normal)
        if isMuted
        {
            audio_switch.isOn = false
        }
        else
        {
            
            audio_switch.isOn = true
            
        }
    }
    
    @IBOutlet weak var pause_lbl: UILabel!
    @IBAction func dismiss_action(_ sender: Any) {
        self.dismiss(animated: true) {
            
        }
    }
    
    @IBAction func finish_action(_ sender: Any) {
        
        self.dismiss(animated: true) {
            self.delegate?.stopMyNavigation()
        }
    }
    
    
    @IBAction func switchAudio_action(_ sender: Any) {
        self.delegate?.manageVoice()
    }
    
    @IBAction func sendEmergencySMS(){
        
        let alertController = UIAlertController(title: "", message:
            NSLocalizedString("ASK_SEND_SMS_EMERGENCY", comment: "ask for confirmation emergency sms"), preferredStyle: UIAlertController.Style.alert)
        alertController.addAction(UIAlertAction(title: NSLocalizedString("CANCEL", comment: ""), style: UIAlertAction.Style.default,handler: nil))
        alertController.addAction(UIAlertAction(title: NSLocalizedString("YES", comment: ""), style: UIAlertAction.Style.destructive,handler: {
            (alert: UIAlertAction!) in
            if (MFMessageComposeViewController.canSendText()) {
                self.delegate?.stopMyNavigation()
                let controller = MFMessageComposeViewController()
                controller.body =  String.localizedStringWithFormat(NSLocalizedString("EMERGENCY_TEXT", comment: "waiting for a GPS signal"), "", "")
                controller.messageComposeDelegate = self
                self.present(controller, animated: true,  completion:{
                    
                })
            }
        }))
        self.present(alertController, animated: true, completion: nil)
    }
    
    
    
}
